package things;

import java.lang.ref.WeakReference;
import java.util.ArrayList;
import java.util.List;
import java.util.ListIterator;
import java.util.Random;

class InputGenerator extends Thread {
    private static final int PERIOD = 100;
    private static final int MAX_VALUE = 1000;

    private final List<WeakReference<Input>> inputs = new ArrayList<>();
    private final Random random = new Random();

    public InputGenerator() {
        random.setSeed(System.currentTimeMillis());
        start();
    }

    public void addInput(Input input) {
        if (input != null) {
            input.setValue(Math.abs(random.nextInt()) % MAX_VALUE);
            inputs.add(new WeakReference<>(input));
        }
    }

    public void run() {
        while (true) {
            ListIterator<WeakReference<Input>> i = inputs.listIterator();
            while (i.hasNext()) {
                Input input = i.next().get();
                if (input != null) {
                    int value = input.getValue() + 1;
                    if (value > MAX_VALUE) value = 0;
                    input.setValue(value);
                } else {
                    i.remove();
                }
            }
            try {
                sleep(PERIOD);
            } catch (InterruptedException e) {
                e.printStackTrace();
            }
        }
    }
}
