package things;

import com.fasterxml.jackson.annotation.JsonView;
import com.fasterxml.jackson.core.JsonProcessingException;

/**
 * Represents an analog output.
 *
 * @see IO
 */
public class Output extends IO {
    private int value = 0;

    Output(Thing parent, String name) {
        super(parent, name);
    }

    @Override
    @JsonView(JSONViews.IODetail.class)
    public int getValue() {
        return value;
    }

    /**
     * Changes the value of the output.
     *
     * @param value New value to set the output to.
     */
    public void setValue(int value) {
        this.value = value;
    }

    /**
     * Updates the output's value using the passed JSON string.
     *
     * @param json  JSON String. Note that the only field required is "value" of type int.
     * @throws JsonProcessingException  In case of JSON parse error.
     */
    public void setJSON(String json) throws JsonProcessingException {
        UpdateBody body = Things.sharedObjectMapper().readValue(json, UpdateBody.class);
        setValue(body.getValue());
    }

    @Override
    public Type getType() {
        return Type.OUTPUT;
    }
}
