package things;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.core.JsonProcessingException;

/**
 * Represents any resource. This can be a things collection, a thing, an input or an output.
 */
public interface Resource {
    /**
     * Enumerates all types of resources.
     */
    enum Type {
        /**
         * The resource is a collection of things.
         *
         * @see things.Things
         */
        THINGS,

        /**
         * The resource is a thing.
         *
         * @see things.Thing
         */
        THING,

        /**
         * The resource is an input.
         *
         * @see things.Input
         */
        INPUT,

        /**
         * The resource is an output.
         *
         * @see things.Output
         */
        OUTPUT
    }

    /**
     * Returns the type of the resource.
     *
     * @return  Type of the resource.
     */
    Type getType();

    /**
     * Returns the name of the resource.
     *
     * @return  Name of the resource.
     */
    @JsonIgnore
    String getName();

    /**
     * Returns the URI of the resource. The URI is unique for every resource object.
     *
     * @return  Resource's URI.
     */
    String getURI();

    /**
     * Serializes the resource to a JSON representation.
     *
     * @return  JSON representation of the resource.
     * @throws JsonProcessingException In case there was an error generating the JSON description.
     */
    @JsonIgnore
    String getJSON() throws JsonProcessingException;
}
